.. role:: hidden
    :class: hidden-section

gpytorch.means
===================================

.. automodule:: gpytorch.means
.. currentmodule:: gpytorch.means


Mean
----------------

.. autoclass:: Mean
   :members:


Standard Means
-----------------------------

:hidden:`ZeroMean`
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: ZeroMean
   :members:

:hidden:`ConstantMean`
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: ConstantMean
   :members:

:hidden:`LinearMean`
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: LinearMean
   :members:


Specialty Means
-----------------------------------

:hidden:`MultitaskMean`
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: MultitaskMean
   :members:

:hidden:`ConstantMeanGrad`
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: ConstantMeanGrad
   :members:

:hidden:`ConstantMeanGradGrad`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: ConstantMeanGradGrad
   :members:

:hidden:`LinearMeanGrad`
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: LinearMeanGrad
   :members:

:hidden:`LinearMeanGradGrad`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: LinearMeanGradGrad
   :members:
